# Generated by roxygen2: do not edit by hand

S3method(coef,svp)
S3method(coef,svp_ged)
S3method(coef,svp_t)
S3method(plot,svp_filter)
S3method(plot,svp_forecast)
S3method(print,svp)
S3method(print,svp_filter)
S3method(print,svp_forecast)
S3method(print,svp_ged)
S3method(print,svp_t)
S3method(print,svp_test)
S3method(summary,svp)
S3method(summary,svp_filter)
S3method(summary,svp_ged)
S3method(summary,svp_t)
export(filter_svp)
export(forecast_svp)
export(lmc_ar)
export(lmc_ged)
export(lmc_lev)
export(lmc_t)
export(mmc_ar)
export(mmc_ged)
export(mmc_lev)
export(mmc_t)
export(sim_svp)
export(svp)
export(svpSE)
export(svp_AR_order)
export(svp_IC)
importFrom(Rcpp,sourceCpp)
importFrom(gsignal,poly)
importFrom(stats,dnorm)
importFrom(stats,pgamma)
importFrom(stats,qgamma)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rchisq)
importFrom(stats,rf)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,uniroot)
importFrom(stats,var)
useDynLib(wARMASVp, .registration = TRUE)
