% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kalman.R
\name{density_eps_t}
\alias{density_eps_t}
\title{Density of Centered log-F(1,nu) Measurement Noise (Student-t)}
\usage{
density_eps_t(y, nu)
}
\arguments{
\item{y}{Numeric vector. Evaluation points (centered: E[eps] = 0).}

\item{nu}{Numeric. Student-t degrees of freedom.}
}
\value{
Density values.
}
\description{
Density of Centered log-F(1,nu) Measurement Noise (Student-t)
}
\keyword{internal}
