% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kalman.R
\name{solve_lyapunov_discrete}
\alias{solve_lyapunov_discrete}
\title{Solve Discrete Lyapunov Equation}
\usage{
solve_lyapunov_discrete(F_mat, Q)
}
\arguments{
\item{F_mat}{Square matrix.}

\item{Q}{Square matrix (same dimensions as \code{F_mat}).}
}
\value{
Solution matrix \code{X}.
}
\description{
Solves X = F X t(F) + Q for X using the vectorization approach.
}
\keyword{internal}
