% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kalman.R
\name{pged_std}
\alias{pged_std}
\title{CDF of Standardized GED}
\usage{
pged_std(u, nu)
}
\arguments{
\item{u}{Numeric vector. Evaluation points.}

\item{nu}{Numeric. GED shape parameter (\eqn{\nu > 0}).}
}
\value{
Numeric vector of probabilities.
}
\description{
Computes the CDF of the standardized GED(\eqn{\nu}) distribution with
unit variance.
}
\keyword{internal}
