% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kalman.R
\name{fit_ksc_mixture}
\alias{fit_ksc_mixture}
\title{Fit K-Component Gaussian Mixture to Measurement Noise Density}
\usage{
fit_ksc_mixture(
  distribution = c("gaussian", "student_t", "ged"),
  nu = NULL,
  K = 7,
  n_sample = 10000,
  max_iter = 500,
  tol = 1e-08,
  seed = 42
)
}
\arguments{
\item{distribution}{Character: \code{"gaussian"}, \code{"student_t"}, or
\code{"ged"}.}

\item{nu}{Numeric. Shape parameter (ignored for Gaussian).}

\item{K}{Integer. Number of mixture components. Default 7.}

\item{n_sample}{Integer. Sample size for EM fitting. Default 10000.}

\item{max_iter}{Integer. Maximum EM iterations. Default 500.}

\item{tol}{Numeric. Convergence tolerance. Default 1e-8.}

\item{seed}{Integer. Random seed. Default 42.}
}
\value{
List with \code{weights}, \code{means}, \code{vars}, \code{KL_div}.
}
\description{
Uses EM algorithm to approximate the measurement noise density with a
Gaussian mixture. For Gaussian SV, returns the pre-computed KSC (1998)
7-component table.
}
\keyword{internal}
